# FinancesPy
A budgeting API for Python.

FinancesPy is an alternative for Gnucash, Mint, Ynab, etc., for Python enthusiasts. It provides an extensible API with a fluent/DSL-like design for managing your finances. The screenshot below shows a sample usage:

![alt text](https://raw.githubusercontent.com/danilomo/FinancesPy/master/sample.png)
